import { createModuleInjection } from '@luma.gl/core';
var vs = "\n  uniform bool brushing_enabled;\n  uniform int brushing_target;\n  uniform vec2 brushing_mousePos;\n  uniform float brushing_radius;\n\n  #ifdef NON_INSTANCED_MODEL\n  attribute vec2 brushingTargets;\n  #else\n  attribute vec2 instanceBrushingTargets;\n  #endif\n\n  varying float brushing_isVisible;\n\n  bool brushing_isPointInRange(vec2 position) {\n    if (!brushing_enabled) {\n      return true;\n    }\n    vec2 source_commonspace = project_position(position);\n    vec2 target_commonspace = project_position(brushing_mousePos);\n    float distance = length((target_commonspace - source_commonspace) / project_uCommonUnitsPerMeter.xy);\n\n    return distance <= brushing_radius;\n  }\n\n  void brushing_setVisible(bool visible) {\n    brushing_isVisible = float(visible);\n  }\n";
var fs = "\n  uniform bool brushing_enabled;\n  varying float brushing_isVisible;\n";
var moduleName = 'brushing';
var TARGET = {
  source: 0,
  target: 1,
  custom: 2
};
createModuleInjection(moduleName, {
  hook: 'vs:DECKGL_FILTER_GL_POSITION',
  injection: "\nvec2 brushingTarget;\nif (brushing_target == 0) {\n  brushingTarget = geometry.worldPosition.xy;\n} else if (brushing_target == 1) {\n  brushingTarget = geometry.worldPositionAlt.xy;\n} else {\n  #ifdef NON_INSTANCED_MODEL\n  brushingTarget = brushingTargets;\n  #else\n  brushingTarget = instanceBrushingTargets;\n  #endif\n}\nbrushing_setVisible(brushing_isPointInRange(brushingTarget));\n  "
});
createModuleInjection(moduleName, {
  hook: 'fs:DECKGL_FILTER_COLOR',
  injection: "\nif (brushing_enabled && brushing_isVisible < 0.5) {\n  discard;\n}\n  "
});
export default {
  name: moduleName,
  dependencies: ['project'],
  vs: vs,
  fs: fs,
  getUniforms: function getUniforms(opts) {
    if (!opts || !opts.viewport) {
      return {};
    }

    var _opts$brushingEnabled = opts.brushingEnabled,
        brushingEnabled = _opts$brushingEnabled === void 0 ? true : _opts$brushingEnabled,
        _opts$brushingRadius = opts.brushingRadius,
        brushingRadius = _opts$brushingRadius === void 0 ? 10000 : _opts$brushingRadius,
        _opts$brushingTarget = opts.brushingTarget,
        brushingTarget = _opts$brushingTarget === void 0 ? 'source' : _opts$brushingTarget,
        mousePosition = opts.mousePosition,
        viewport = opts.viewport;
    return {
      brushing_enabled: Boolean(brushingEnabled && mousePosition && viewport.containsPixel(mousePosition)),
      brushing_radius: brushingRadius,
      brushing_target: TARGET[brushingTarget] || 0,
      brushing_mousePos: mousePosition ? viewport.unproject([mousePosition.x - viewport.x, mousePosition.y - viewport.y]) : [0, 0]
    };
  }
};
//# sourceMappingURL=shader-module.js.map